/**
 * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'tt', {
	button: 'Код өзеген өстәү',
	codeContents: 'Код эчтәлеге',
	emptySnippetError: 'Код өзеге буш булмаска тиеш.',
	language: 'Тел',
	title: 'Код өзеге',
	pathName: 'код өзеге'
} );
